@@ -25,15 +25,20 @@ Tool for generating a sample configuration file. See
 
 import collections
 import copy
+import json
 import logging
 import operator
 import sys
 import textwrap
 
-import json
-import pkg_resources
-import yaml
+try:
+    # For Python 3.8 and later
+    import importlib.metadata as importlib_metadata
+except ImportError:
+    # For everyone else
+    import importlib_metadata
 
+import yaml
 
 from oslo_config import cfg
 import stevedore.named  # noqa
@@ -765,7 +770,7 @@ def generate(conf, output_file=None):
 
 def main(args=None):
     """The main function of oslo-config-generator."""
-    version = pkg_resources.get_distribution('oslo.config').version
+    version = importlib_metadata.version('oslo.config')
     logging.basicConfig(level=logging.WARN)
     conf = cfg.ConfigOpts()
     register_cli_opts(conf)
