@@ -15,7 +15,6 @@ from docutils.parsers import rst
 from docutils.parsers.rst import directives
 from docutils.statemachine import ViewList
 import oslo_i18n
-import six
 from sphinx import addnodes
 from sphinx.directives import ObjectDescription
 from sphinx.domains import Domain
@@ -89,7 +88,7 @@ def _get_choice_text(choice):
         return '<None>'
     elif choice == '':
         return "''"
-    return six.text_type(choice)
+    return str(choice)
 
 
 def _format_opt(opt, group_name):
@@ -474,6 +473,7 @@ class ConfigDomain(Domain):
 
     def resolve_xref(self, env, fromdocname, builder,
                      typ, target, node, contnode):
+        """Resolve cross-references"""
         if typ == 'option':
             group_name, option_name = target.split('.', 1)
             return make_refnode(
@@ -508,3 +508,7 @@ def setup(app):
     oslo_i18n.enable_lazy(False)
     app.add_directive('show-options', ShowOptionsDirective)
     app.add_domain(ConfigDomain)
+    return {
+        'parallel_read_safe': True,
+        'parallel_write_safe': True,
+    }
